ManimPango's documentation!
===========================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   reference
   RELEASE

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
